@@ -161,6 +161,9 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
+def get_last_price(ssj = 'BTC', ssj_against = 'USDT'):
+    r = requests.get(f'https://min-api.cryptocompare.com/data/price?fsym={ssj}&tsyms={ssj_against}')
+    return json.loads(r.text)[ssj_against]
 
 def get_npx_hitbtc_bindex_spread(depth = 1):
     hbid, hask = fetch_rest_hitbtc_orderbook()
